==> google-cloud-build-3.14.0.tar.gz: google-cloud-build-3.14.0/google/cloud/devtools/cloudbuild_v1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .cloudbuild import (
    ApprovalConfig,
    ApprovalResult,
    ApproveBuildRequest,
    ArtifactResult,
    Artifacts,
    Build,
    BuildApproval,
    BuildOperationMetadata,
    BuildOptions,
    BuildStep,
    BuildTrigger,
    BuiltImage,
    CancelBuildRequest,
    CreateBuildRequest,
    CreateBuildTriggerRequest,
    CreateWorkerPoolOperationMetadata,
    CreateWorkerPoolRequest,
    DeleteBuildTriggerRequest,
    DeleteWorkerPoolOperationMetadata,
    DeleteWorkerPoolRequest,
    FileHashes,
    GetBuildRequest,
    GetBuildTriggerRequest,
    GetWorkerPoolRequest,
    GitHubEventsConfig,
    Hash,
    InlineSecret,
    ListBuildsRequest,
    ListBuildsResponse,
    ListBuildTriggersRequest,
    ListBuildTriggersResponse,
    ListWorkerPoolsRequest,
    ListWorkerPoolsResponse,
    PrivatePoolV1Config,
    PubsubConfig,
    PullRequestFilter,
    PushFilter,
    ReceiveTriggerWebhookRequest,
    ReceiveTriggerWebhookResponse,
    RepoSource,
    Results,
    RetryBuildRequest,
    RunBuildTriggerRequest,
    Secret,
    SecretManagerSecret,
    Secrets,
    Source,
    SourceProvenance,
    StorageSource,
    StorageSourceManifest,
    TimeSpan,
    UpdateBuildTriggerRequest,
    UpdateWorkerPoolOperationMetadata,
    UpdateWorkerPoolRequest,
    UploadedMavenArtifact,
    UploadedPythonPackage,
    Volume,
    WebhookConfig,
    WorkerPool,
)

__all__ = (
    "ApprovalConfig",
    "ApprovalResult",
    "ApproveBuildRequest",
    "ArtifactResult",
    "Artifacts",
    "Build",
    "BuildApproval",
    "BuildOperationMetadata",
    "BuildOptions",
    "BuildStep",
    "BuildTrigger",
    "BuiltImage",
    "CancelBuildRequest",
    "CreateBuildRequest",
    "CreateBuildTriggerRequest",
    "CreateWorkerPoolOperationMetadata",
    "CreateWorkerPoolRequest",
    "DeleteBuildTriggerRequest",
    "DeleteWorkerPoolOperationMetadata",
    "DeleteWorkerPoolRequest",
    "FileHashes",
    "GetBuildRequest",
    "GetBuildTriggerRequest",
    "GetWorkerPoolRequest",
    "GitHubEventsConfig",
    "Hash",
    "InlineSecret",
    "ListBuildsRequest",
    "ListBuildsResponse",
    "ListBuildTriggersRequest",
    "ListBuildTriggersResponse",
    "ListWorkerPoolsRequest",
    "ListWorkerPoolsResponse",
    "PrivatePoolV1Config",
    "PubsubConfig",
    "PullRequestFilter",
    "PushFilter",
    "ReceiveTriggerWebhookRequest",
    "ReceiveTriggerWebhookResponse",
    "RepoSource",
    "Results",
    "RetryBuildRequest",
    "RunBuildTriggerRequest",
    "Secret",
    "SecretManagerSecret",
    "Secrets",
    "Source",
    "SourceProvenance",
    "StorageSource",
    "StorageSourceManifest",
    "TimeSpan",
    "UpdateBuildTriggerRequest",
    "UpdateWorkerPoolOperationMetadata",
    "UpdateWorkerPoolRequest",
    "UploadedMavenArtifact",
    "UploadedPythonPackage",
    "Volume",
    "WebhookConfig",
    "WorkerPool",
)

==> google-cloud-build-3.22.0.tar.gz: google-cloud-build-3.22.0/google/cloud/devtools/cloudbuild_v1/types/__init__.py <==
# -*- coding: utf-8 -*-
# Copyright 2023 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .cloudbuild import (
    ApprovalConfig,
    ApprovalResult,
    ApproveBuildRequest,
    ArtifactResult,
    Artifacts,
    Build,
    BuildApproval,
    BuildOperationMetadata,
    BuildOptions,
    BuildStep,
    BuildTrigger,
    BuiltImage,
    CancelBuildRequest,
    CreateBuildRequest,
    CreateBuildTriggerRequest,
    CreateWorkerPoolOperationMetadata,
    CreateWorkerPoolRequest,
    DeleteBuildTriggerRequest,
    DeleteWorkerPoolOperationMetadata,
    DeleteWorkerPoolRequest,
    FileHashes,
    GetBuildRequest,
    GetBuildTriggerRequest,
    GetWorkerPoolRequest,
    GitFileSource,
    GitHubEnterpriseConfig,
    GitHubEnterpriseSecrets,
    GitHubEventsConfig,
    GitRepoSource,
    GitSource,
    Hash,
    InlineSecret,
    ListBuildsRequest,
    ListBuildsResponse,
    ListBuildTriggersRequest,
    ListBuildTriggersResponse,
    ListWorkerPoolsRequest,
    ListWorkerPoolsResponse,
    PrivatePoolV1Config,
    PubsubConfig,
    PullRequestFilter,
    PushFilter,
    ReceiveTriggerWebhookRequest,
    ReceiveTriggerWebhookResponse,
    RepositoryEventConfig,
    RepoSource,
    Results,
    RetryBuildRequest,
    RunBuildTriggerRequest,
    Secret,
    SecretManagerSecret,
    Secrets,
    Source,
    SourceProvenance,
    StorageSource,
    StorageSourceManifest,
    TimeSpan,
    UpdateBuildTriggerRequest,
    UpdateWorkerPoolOperationMetadata,
    UpdateWorkerPoolRequest,
    UploadedMavenArtifact,
    UploadedNpmPackage,
    UploadedPythonPackage,
    Volume,
    WebhookConfig,
    WorkerPool,
)

__all__ = (
    "ApprovalConfig",
    "ApprovalResult",
    "ApproveBuildRequest",
    "ArtifactResult",
    "Artifacts",
    "Build",
    "BuildApproval",
    "BuildOperationMetadata",
    "BuildOptions",
    "BuildStep",
    "BuildTrigger",
    "BuiltImage",
    "CancelBuildRequest",
    "CreateBuildRequest",
    "CreateBuildTriggerRequest",
    "CreateWorkerPoolOperationMetadata",
    "CreateWorkerPoolRequest",
    "DeleteBuildTriggerRequest",
    "DeleteWorkerPoolOperationMetadata",
    "DeleteWorkerPoolRequest",
    "FileHashes",
    "GetBuildRequest",
    "GetBuildTriggerRequest",
    "GetWorkerPoolRequest",
    "GitFileSource",
    "GitHubEnterpriseConfig",
    "GitHubEnterpriseSecrets",
    "GitHubEventsConfig",
    "GitRepoSource",
    "GitSource",
    "Hash",
    "InlineSecret",
    "ListBuildsRequest",
    "ListBuildsResponse",
    "ListBuildTriggersRequest",
    "ListBuildTriggersResponse",
    "ListWorkerPoolsRequest",
    "ListWorkerPoolsResponse",
    "PrivatePoolV1Config",
    "PubsubConfig",
    "PullRequestFilter",
    "PushFilter",
    "ReceiveTriggerWebhookRequest",
    "ReceiveTriggerWebhookResponse",
    "RepositoryEventConfig",
    "RepoSource",
    "Results",
    "RetryBuildRequest",
    "RunBuildTriggerRequest",
    "Secret",
    "SecretManagerSecret",
    "Secrets",
    "Source",
    "SourceProvenance",
    "StorageSource",
    "StorageSourceManifest",
    "TimeSpan",
    "UpdateBuildTriggerRequest",
    "UpdateWorkerPoolOperationMetadata",
    "UpdateWorkerPoolRequest",
    "UploadedMavenArtifact",
    "UploadedNpmPackage",
    "UploadedPythonPackage",
    "Volume",
    "WebhookConfig",
    "WorkerPool",
)
